Method: Selenium::SeleniumDriver#type
- Defined in:
- lib/selenium-client.rb
#type(locator, value) ⇒ Object
Sets the value of an input field, as though you typed it in.
Can also be used to set the value of combo boxes, check boxes, etc. In these cases, value should be the value of the option selected, not the visible text.
‘locator’ is an element locator ‘value’ is the value to type
536 537 538 |
# File 'lib/selenium-client.rb', line 536 def type(locator,value) do_command("type", [locator,value,]) end |